'''OpenGL extension EXT.depth_clamp

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.depth_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	Conventional OpenGL clips geometric primitives to a clip volume
	with six faces, two of which are the near and far clip planes.
	Clipping to the near and far planes of the clip volume ensures that
	interpolated depth values (after the depth range transform) must be
	in the [0,1] range.
	
	In some rendering applications such as shadow volumes, it is useful
	to allow line and polygon primitives to be rasterized without
	clipping the primitive to the near or far clip volume planes (side
	clip volume planes clip normally).  Without the near and far clip
	planes, rasterization (pixel coverage determination) in X and Y
	can proceed normally if we ignore the near and far clip planes.
	The one major issue is that fragments of a  primitive may extend
	beyond the conventional window space depth range for depth values
	(typically the range [0,1]).  Rather than discarding fragments that
	defy the window space depth range (effectively what near and far
	plane clipping accomplish), the depth values can be clamped to the
	current depth range.
	
	This extension provides exactly such functionality.  This
	functionality is useful to obviate the need for near plane capping
	of stenciled shadow volumes.  The functionality may also be useful
	for rendering geometry "beyond" the far plane if an alternative
	algorithm (rather than depth testing) for hidden surface removal is
	applied to such geometry (specifically, the painter's algorithm).
	Similar situations at the near clip plane can be avoided at the
	near clip plane where apparently solid objects can be "seen through"
	if they intersect the near clip plane.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/depth_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.depth_clamp import *
from OpenGL.raw.GLES2.EXT.depth_clamp import _EXTENSION_NAME

def glInitDepthClampEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_viewport_swizzle'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_viewport_swizzle',error_checker=_errors._error_checker)
GL_VIEWPORT_SWIZZLE_NEGATIVE_W_NV=_C('GL_VIEWPORT_SWIZZLE_NEGATIVE_W_NV',0x9357)
GL_VIEWPORT_SWIZZLE_NEGATIVE_X_NV=_C('GL_VIEWPORT_SWIZZLE_NEGATIVE_X_NV',0x9351)
GL_VIEWPORT_SWIZZLE_NEGATIVE_Y_NV=_C('GL_VIEWPORT_SWIZZLE_NEGATIVE_Y_NV',0x9353)
GL_VIEWPORT_SWIZZLE_NEGATIVE_Z_NV=_C('GL_VIEWPORT_SWIZZLE_NEGATIVE_Z_NV',0x9355)
GL_VIEWPORT_SWIZZLE_POSITIVE_W_NV=_C('GL_VIEWPORT_SWIZZLE_POSITIVE_W_NV',0x9356)
GL_VIEWPORT_SWIZZLE_POSITIVE_X_NV=_C('GL_VIEWPORT_SWIZZLE_POSITIVE_X_NV',0x9350)
GL_VIEWPORT_SWIZZLE_POSITIVE_Y_NV=_C('GL_VIEWPORT_SWIZZLE_POSITIVE_Y_NV',0x9352)
GL_VIEWPORT_SWIZZLE_POSITIVE_Z_NV=_C('GL_VIEWPORT_SWIZZLE_POSITIVE_Z_NV',0x9354)
GL_VIEWPORT_SWIZZLE_W_NV=_C('GL_VIEWPORT_SWIZZLE_W_NV',0x935B)
GL_VIEWPORT_SWIZZLE_X_NV=_C('GL_VIEWPORT_SWIZZLE_X_NV',0x9358)
GL_VIEWPORT_SWIZZLE_Y_NV=_C('GL_VIEWPORT_SWIZZLE_Y_NV',0x9359)
GL_VIEWPORT_SWIZZLE_Z_NV=_C('GL_VIEWPORT_SWIZZLE_Z_NV',0x935A)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glViewportSwizzleNV(index,swizzlex,swizzley,swizzlez,swizzlew):pass



'''OpenGL extension ARB.shader_texture_lod

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_texture_lod to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds additional texture functions to the
	OpenGL Shading Language which provide the shader writer
	with explicit control of LOD.
	
	Mipmap texture fetches and anisotropic texture fetches
	require an implicit derivatives to calculate rho, lambda
	and/or the line of anisotropy.  These implicit derivatives
	will be undefined for texture fetches occurring inside
	non-uniform control flow or for vertex shader texture
	fetches, resulting in undefined texels.
	
	The additional texture functions introduced with
	this extension provide explict control of LOD
	(isotropic texture functions) or provide explicit
	derivatives (anisotropic texture functions).
	
	Anisotropic texture functions return defined texels
	for mipmap texture fetches or anisotropic texture fetches,
	even inside non-uniform control flow.  Isotropic texture
	functions return defined texels for mipmap texture fetches,
	even inside non-uniform control flow.  However, isotropic
	texture functions return undefined texels for anisotropic
	texture fetches.
	
	The existing isotropic vertex texture functions:
	
	    texture1DLod,   texture1DProjLod,
	    texture2DLod,   texture2DProjLod,
	    texture3DLod,   texture3DProjLod,
	    textureCubeLod,
	    shadow1DLod,    shadow1DProjLod,
	    shadow2DLod,    shadow2DProjLod,
	
	are added to the built-in functions for fragment shaders.
	
	New anisotropic texture functions, providing explicit
	derivatives:
	
	    texture1DGradARB(         sampler1D sampler,
	                              float P, float dPdx, float dPdy );
	    texture1DProjGradARB(     sampler1D sampler,
	                              vec2  P, float dPdx, float dPdy );
	    texture1DProjGradARB(     sampler1D sampler,
	                              vec4  P, float dPdx, float dPdy );
	
	    texture2DGradARB(         sampler2D sampler,
	                              vec2  P, vec2  dPdx, vec2  dPdy );
	    texture2DProjGradARB(     sampler2D sampler,
	                              vec3  P, vec2  dPdx, vec2  dPdy );
	    texture2DProjGradARB(     sampler2D sampler,
	                              vec4  P, vec2  dPdx, vec2  dPdy );
	
	    texture3DGradARB(         sampler3D sampler,
	                              vec3  P, vec3  dPdx, vec3  dPdy );
	    texture3DProjGradARB(     sampler3D sampler,
	                              vec4  P, vec3  dPdx, vec3  dPdy );
	
	    textureCubeGradARB(       samplerCube sampler,
	                              vec3  P, vec3  dPdx, vec3  dPdy );
	
	    shadow1DGradARB(          sampler1DShadow sampler,
	                              vec3  P, float dPdx, float dPdy );
	    shadow1DProjGradARB(      sampler1DShadow sampler,
	                              vec4  P, float dPdx, float dPdy );
	
	    shadow2DGradARB(          sampler2DShadow sampler,
	                              vec3  P, vec2  dPdx, vec2  dPdy );
	    shadow2DProjGradARB(      sampler2DShadow sampler,
	                              vec4  P, vec2  dPdx, vec2  dPdy );
	
	
	    texture2DRectGradARB(     sampler2DRect sampler,
	                              vec2  P, vec2  dPdx, vec2  dPdy );
	    texture2DRectProjGradARB( sampler2DRect sampler,
	                              vec3  P, vec2  dPdx, vec2  dPdy );
	    texture2DRectProjGradARB( sampler2DRect sampler,
	                              vec4  P, vec2  dPdx, vec2  dPdy );
	
	    shadow2DRectGradARB(      sampler2DRectShadow sampler,
	                              vec3  P, vec2  dPdx, vec2  dPdy );
	    shadow2DRectProjGradARB(  sampler2DRectShadow sampler,
	                              vec4  P, vec2  dPdx, vec2  dPdy );
	
	 are added to the built-in functions for vertex shaders
	 and fragment shaders.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_texture_lod.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_texture_lod import *
from OpenGL.raw.GL.ARB.shader_texture_lod import _EXTENSION_NAME

def glInitShaderTextureLodARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_3_3'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_3_3',error_checker=_errors._error_checker)
GL_ANY_SAMPLES_PASSED=_C('GL_ANY_SAMPLES_PASSED',0x8C2F)
GL_INT_2_10_10_10_REV=_C('GL_INT_2_10_10_10_REV',0x8D9F)
GL_MAX_DUAL_SOURCE_DRAW_BUFFERS=_C('GL_MAX_DUAL_SOURCE_DRAW_BUFFERS',0x88FC)
GL_ONE_MINUS_SRC1_ALPHA=_C('GL_ONE_MINUS_SRC1_ALPHA',0x88FB)
GL_ONE_MINUS_SRC1_COLOR=_C('GL_ONE_MINUS_SRC1_COLOR',0x88FA)
GL_RGB10_A2UI=_C('GL_RGB10_A2UI',0x906F)
GL_SAMPLER_BINDING=_C('GL_SAMPLER_BINDING',0x8919)
GL_SRC1_COLOR=_C('GL_SRC1_COLOR',0x88F9)
GL_TEXTURE_SWIZZLE_A=_C('GL_TEXTURE_SWIZZLE_A',0x8E45)
GL_TEXTURE_SWIZZLE_B=_C('GL_TEXTURE_SWIZZLE_B',0x8E44)
GL_TEXTURE_SWIZZLE_G=_C('GL_TEXTURE_SWIZZLE_G',0x8E43)
GL_TEXTURE_SWIZZLE_R=_C('GL_TEXTURE_SWIZZLE_R',0x8E42)
GL_TEXTURE_SWIZZLE_RGBA=_C('GL_TEXTURE_SWIZZLE_RGBA',0x8E46)
GL_TIMESTAMP=_C('GL_TIMESTAMP',0x8E28)
GL_TIME_ELAPSED=_C('GL_TIME_ELAPSED',0x88BF)
GL_VERTEX_ATTRIB_ARRAY_DIVISOR=_C('GL_VERTEX_ATTRIB_ARRAY_DIVISOR',0x88FE)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glBindFragDataLocationIndexed(program,colorNumber,index,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glBindSampler(unit,sampler):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glColorP3ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glColorP3uiv(type,color):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glColorP4ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glColorP4uiv(type,color):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteSamplers(count,samplers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenSamplers(count,samplers):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetFragDataIndex(program,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glGetQueryObjecti64v(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetQueryObjectui64v(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetSamplerParameterIiv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetSamplerParameterIuiv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetSamplerParameterfv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetSamplerParameteriv(sampler,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsSampler(sampler):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP1ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP1uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP2ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP2uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP3ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP3uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP4ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP4uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glNormalP3ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glNormalP3uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glQueryCounter(id,target):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glSamplerParameterIiv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glSamplerParameterIuiv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLfloat)
def glSamplerParameterf(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glSamplerParameterfv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glSamplerParameteri(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glSamplerParameteriv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glSecondaryColorP3ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glSecondaryColorP3uiv(type,color):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP1ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP1uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP2ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP2uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP3ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP3uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP4ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP4uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribDivisor(index,divisor):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP1ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP1uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP2ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP2uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP3ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP3uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP4ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP4uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP2ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP2uiv(type,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP3ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP3uiv(type,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP4ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP4uiv(type,value):pass



'''OpenGL extension OES.point_sprite

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.point_sprite to provide a more 
Python-friendly API

Overview (from the spec)
	
	Applications such as particle systems have tended to use OpenGL quads
	rather than points to render their geometry, since they would like
	to use a custom-drawn texture for each particle, rather than the
	traditional OpenGL round antialiased points, and each fragment in
	a point has the same texture coordinates as every other fragment.
	
	Unfortunately, specifying the geometry for these quads can be
	expensive, since it quadruples the amount of geometry required, and
	may also require the application to do extra processing to compute
	the location of each vertex.
	
	The purpose of this extension is to allow such applications to use
	points rather than quads.  When GL_POINT_SPRITE_OES is enabled,
	the state of point antialiasing is ignored.  For each texture unit,
	the app can then specify whether to replace the existing texture
	coordinates with point sprite texture coordinates, which are
	interpolated across the point.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/point_sprite.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.point_sprite import *
from OpenGL.raw.GLES1.OES.point_sprite import _EXTENSION_NAME

def glInitPointSpriteOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.memory_attachment

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.memory_attachment to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the memory objects introduced with EXT_memory_object
	to allow existing textures and buffers to be migrated to an imported memory
	allocation.  The primary use-case of this extension is plug-in development
	where resource management (creation, deletion, sizing etc.) is handled by
	inaccessible host application code.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/memory_attachment.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.memory_attachment import *
from OpenGL.raw.GLES2.NV.memory_attachment import _EXTENSION_NAME

def glInitMemoryAttachmentNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.EGL_sync

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.EGL_sync to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends EGL_KHR_fence_sync with client API support for
	OpenGL (compatibility or core profiles) as an EXT extension.
	
	The "GL_EXT_EGL_sync" string indicates that a fence sync object can be
	created in association with a fence command placed in the command stream
	of a bound OpenGL context.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/EGL_sync.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.EGL_sync import *
from OpenGL.raw.GL.EXT.EGL_sync import _EXTENSION_NAME

def glInitEglSyncEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.debug_marker

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.debug_marker to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism for OpenGL and OpenGL ES applications to
	annotate their command stream with markers for discrete events and groups 
	of commands using descriptive text markers. 
	
	When profiling or debugging such an application within a debugger or 
	profiler it is difficult to relate the commands within the command stream 
	to the elements of the scene or parts of the program code to which they 
	correspond. Markers help obviate this by allowing applications to specify 
	this link.
	
	The intended purpose of this is purely to improve the user experience 
	within OpenGL and OpenGL ES development tools.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/debug_marker.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.debug_marker import *
from OpenGL.raw.GL.EXT.debug_marker import _EXTENSION_NAME

def glInitDebugMarkerEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.create_context_no_error

This module customises the behaviour of the 
OpenGL.raw.WGL.ARB.create_context_no_error to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the creation of an OpenGL or OpenGL ES context that
	doesn't generate errors if the context supports a no error mode.  The
	implications of this feature are discussed in the GL_KHR_no_error
	extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/create_context_no_error.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.ARB.create_context_no_error import *
from OpenGL.raw.WGL.ARB.create_context_no_error import _EXTENSION_NAME

def glInitCreateContextNoErrorARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.framebuffer_multisample

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.framebuffer_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the framebuffer object framework to
	enable multisample rendering.
	
	The new operation RenderbufferStorageMultisampleNV() allocates
	storage for a renderbuffer object that can be used as a multisample
	buffer.  A multisample render buffer image differs from a
	single-sample render buffer image in that a multisample image has a
	number of SAMPLES that is greater than zero.  No method is provided
	for creating multisample texture images.
	
	All of the framebuffer-attachable images attached to a framebuffer
	object must have the same number of SAMPLES or else the framebuffer
	object is not "framebuffer complete".  If a framebuffer object with
	multisample attachments is "framebuffer complete", then the
	framebuffer object behaves as if SAMPLE_BUFFERS is one.
	
	A resolve operation is executed by calling
	BlitFramebufferNV (provided by the NV_framebuffer_blit
	extension) where the source is a multisample framebuffer object
	and the destination is a single-sample framebuffer object.
	Source and destination framebuffer may be either application-created
	or window-system provided.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/framebuffer_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.framebuffer_multisample import *
from OpenGL.raw.GLES2.NV.framebuffer_multisample import _EXTENSION_NAME

def glInitFramebufferMultisampleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_gpu_multicast'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_gpu_multicast',error_checker=_errors._error_checker)
GL_MULTICAST_GPUS_NV=_C('GL_MULTICAST_GPUS_NV',0x92BA)
GL_MULTICAST_PROGRAMMABLE_SAMPLE_LOCATION_NV=_C('GL_MULTICAST_PROGRAMMABLE_SAMPLE_LOCATION_NV',0x9549)
GL_PER_GPU_STORAGE_BIT_NV=_C('GL_PER_GPU_STORAGE_BIT_NV',0x0800)
GL_PER_GPU_STORAGE_NV=_C('GL_PER_GPU_STORAGE_NV',0x9548)
GL_RENDER_GPU_MASK_NV=_C('GL_RENDER_GPU_MASK_NV',0x9558)
@_f
@_p.types(None,)
def glMulticastBarrierNV():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glMulticastBlitFramebufferNV(srcGpu,dstGpu,srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(None,_cs.GLbitfield,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr,ctypes.c_void_p)
def glMulticastBufferSubDataNV(gpuMask,buffer,offset,size,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLintptr,_cs.GLsizeiptr)
def glMulticastCopyBufferSubDataNV(readGpu,writeGpuMask,readBuffer,writeBuffer,readOffset,writeOffset,size):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glMulticastCopyImageSubDataNV(srcGpu,dstGpuMask,srcName,srcTarget,srcLevel,srcX,srcY,srcZ,dstName,dstTarget,dstLevel,dstX,dstY,dstZ,srcWidth,srcHeight,srcDepth):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glMulticastFramebufferSampleLocationsfvNV(gpu,framebuffer,start,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glMulticastGetQueryObjecti64vNV(gpu,id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glMulticastGetQueryObjectivNV(gpu,id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glMulticastGetQueryObjectui64vNV(gpu,id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glMulticastGetQueryObjectuivNV(gpu,id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield)
def glMulticastWaitSyncNV(signalGpu,waitGpuMask):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glRenderGpuMaskNV(mask):pass



'''OpenGL extension NV.viewport_array2

This module customises the behaviour of the 
OpenGL.raw.GL.NV.viewport_array2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides new support allowing a single primitive to be
	broadcast to multiple viewports and/or multiple layers.  A shader output
	gl_ViewportMask[] is provided, allowing a single primitive to be output to
	multiple viewports simultaneously.  Also, a new shader option is provided
	to control whether the effective viewport index is added into gl_Layer.
	These capabilities allow a single primitive to be output to multiple
	layers simultaneously.
	
	The gl_ViewportMask[] output is available in vertex, tessellation
	control, tessellation evaluation, and geometry shaders. gl_ViewportIndex
	and gl_Layer are also made available in all these shader stages. The
	actual viewport index or mask and render target layer values are taken
	from the last active shader stage from this set of stages.
	
	This extension is a superset of the GL_AMD_vertex_shader_layer and
	GL_AMD_vertex_shader_viewport_index extensions, and thus those extension
	strings are expected to be exported if GL_NV_viewport_array2 is
	supported. This extension includes the edits for those extensions, recast
	against the reorganized OpenGL 4.3 specification.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/viewport_array2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.viewport_array2 import *
from OpenGL.raw.GL.NV.viewport_array2 import _EXTENSION_NAME

def glInitViewportArray2NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.fill_rectangle

This module customises the behaviour of the 
OpenGL.raw.GL.NV.fill_rectangle to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a new PolygonMode setting where a triangle is
	rasterized by computing and filling its axis-aligned screen-space bounding
	box, disregarding the actual triangle edges. This can be useful for
	drawing a rectangle without being split into two triangles with an
	internal edge.  It is also useful to minimize the number of primitives
	that need to be drawn, particularly for a user-interface.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/fill_rectangle.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.fill_rectangle import *
from OpenGL.raw.GL.NV.fill_rectangle import _EXTENSION_NAME

def glInitFillRectangleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""OpenGL-wide constant types (not OpenGL.GL-specific)

These are basically the fundamental data-types that OpenGL 
uses (note, doesn't include the OpenGL-ES types!)
"""
import ctypes
from OpenGL.constant import Constant
from OpenGL._bytes import bytes,unicode,as_8_bit, long
assert unicode
assert as_8_bit
from OpenGL._opaque import opaque_pointer_cls as _opaque_pointer_cls

sizeof = ctypes.sizeof
GL_FALSE = Constant( 'GL_FALSE', 0x0 )
GL_TRUE = Constant( 'GL_TRUE', 0x1 )
GL_BYTE = Constant( 'GL_BYTE', 0x1400 )
GL_UNSIGNED_BYTE = Constant( 'GL_UNSIGNED_BYTE', 0x1401 )
GL_SHORT = Constant( 'GL_SHORT', 0x1402 )
GL_UNSIGNED_SHORT = Constant( 'GL_UNSIGNED_SHORT', 0x1403 )
GL_INT = Constant( 'GL_INT', 0x1404 )
GL_UNSIGNED_INT = Constant( 'GL_UNSIGNED_INT', 0x1405 )
GL_UNSIGNED_INT64 = Constant( 'GL_UNSIGNED_INT64_AMD', 0x8BC2 )
GL_FLOAT = Constant( 'GL_FLOAT', 0x1406 )
GL_DOUBLE = Constant( 'GL_DOUBLE', 0x140a )
GL_CHAR = bytes
GL_HALF_FLOAT = Constant( 'GL_HALF_FLOAT_ARB',0x140B)
GL_HALF_NV = Constant( 'GL_HALF_NV', 0x1401 )
GL_FIXED=Constant('GL_FIXED',0x140C)
GL_VOID_P = object()

def _get_ctypes_version():
    return [int(i) for i in ctypes.__version__.split('.')[:3]]
ctypes_version = _get_ctypes_version()

# Basic OpenGL data-types as ctypes declarations...
def _defineType( name, baseType, convertFunc = long ):
    from OpenGL import _configflags
    do_wrapping = (
        _configflags.ALLOW_NUMPY_SCALARS or # explicitly require
        (( # or we are using Python 2.5.x ctypes which doesn't support uint type numpy scalars
            ctypes_version < [1,1,0]
            and baseType in (ctypes.c_uint,ctypes.c_uint64,ctypes.c_ulong,ctypes.c_ushort)
        ) or
        ( # or we are using Python 2.5.x (x < 2) ctypes which doesn't support any numpy int scalars
            ctypes_version < [1,0,2]
            and baseType in (ctypes.c_int,ctypes.c_int64,ctypes.c_long,ctypes.c_short)
        ))
    )
    if do_wrapping:
        original = baseType.from_param
        if not getattr( original, 'from_param_numpy_scalar', False ):
            def from_param( x, typeCode=None ):
                try:
                    return original( x )
                except TypeError as err:
                    try:
                        return original( convertFunc(x) )
                    except TypeError:
                        raise err
            from_param = staticmethod( from_param )
            setattr( baseType, 'from_param', from_param )
            baseType.from_param_numpy_scalar = True
        return baseType
    else:
        return baseType

GLvoid = None
GLboolean = _defineType( 'GLboolean', ctypes.c_ubyte, bool )
GLenum = _defineType( 'GLenum', ctypes.c_uint )

GLfloat = _defineType( 'GLfloat', ctypes.c_float, float )
GLfloat_2 = GLfloat * 2
GLfloat_3 = GLfloat * 3
GLfloat_4 = GLfloat * 4
GLdouble = _defineType( 'GLdouble', ctypes.c_double, float )
GLdouble_2 = GLdouble * 2
GLdouble_3 = GLdouble * 3
GLdouble_4 = GLdouble * 4

GLbyte = ctypes.c_byte
GLshort = _defineType( 'GLshort', ctypes.c_short, int )
GLint = _defineType( 'GLint', ctypes.c_int, int )
GLuint = _defineType( 'GLuint', ctypes.c_uint, long )
GLfixed = _defineType('GLfixed', ctypes.c_int32, int )
GLclampx = _defineType('GLclampx', ctypes.c_int32, int )

# This is explicitly called out as equivalent to a uint
GLsizei = _defineType( 'GLsizei', ctypes.c_uint, long )
# Signed 2's complement binary integer with sizeof( void * )
GLintptr = _defineType( 'GLintptr', ctypes.c_ssize_t, int )
# Unsigned size-of-x
GLsizeiptr = _defineType( 'GLsizeiptr', ctypes.c_size_t, int )

GLubyte = ctypes.c_ubyte
GLubyte_3 = GLubyte * 3
GLushort = _defineType( 'GLushort', ctypes.c_ushort, int )
GLulong = _defineType( 'GLulong', ctypes.c_ulong, int )
GLhandleARB = _defineType( 'GLhandleARB', ctypes.c_uint, long )
GLhandle = _defineType( 'GLhandle', ctypes.c_uint, long )

GLchar = GLcharARB = ctypes.c_char

GLbitfield = _defineType( 'GLbitfield', ctypes.c_uint, long )

GLclampd = _defineType( 'GLclampd', ctypes.c_double, float )
GLclampf = _defineType( 'GLclampf', ctypes.c_float, float )

GLuint64 = GLuint64EXT = _defineType('GLuint64', ctypes.c_uint64, long )
GLint64 = GLint64EXT = _defineType('GLint64', ctypes.c_int64, long )

# ptrdiff_t, actually...
GLsizeiptrARB = GLsizeiptr
GLvdpauSurfaceNV = GLintptrARB = GLintptr
size_t = ctypes.c_size_t
int32_t = ctypes.c_int32
int64_t = ctypes.c_int64

void = None

# this is *wrong*, half is a *float* type, but ctypes doesn't have 16-bit float support
GLhalfNV = GLhalfARB = ctypes.c_ushort

# GL.ARB.sync extension, GLsync is an opaque pointer to a struct 
# in the extensions header, basically just a "token" that can be 
# passed to the various operations...
GLsync = _opaque_pointer_cls( 'GLsync' )
GLvoidp = ctypes.c_void_p

ARRAY_TYPE_TO_CONSTANT = [
    ('GLclampd', GL_DOUBLE),
    ('GLclampf', GL_FLOAT),
    ('GLfloat', GL_FLOAT),
    ('GLdouble', GL_DOUBLE),
    ('GLbyte', GL_BYTE),
    ('GLshort', GL_SHORT),
    ('GLint', GL_INT),
    ('GLubyte', GL_UNSIGNED_BYTE),
    ('GLushort', GL_UNSIGNED_SHORT),
    ('GLuint', GL_UNSIGNED_INT),
    ('GLenum', GL_UNSIGNED_INT),
]

from OpenGL.platform import PLATFORM as _p

GLDEBUGPROCARB = GLDEBUGPROCKHR = GLDEBUGPROC = _p.DEFAULT_FUNCTION_TYPE(
    void, 
    GLenum,  # source,
    GLenum, #type,
    GLuint, # id 
    GLenum, # severity
    GLsizei, # length
    ctypes.c_char_p, # message 
    GLvoidp, # userParam
)

class _cl_context( ctypes.Structure ):
    """Placeholder/empty structure for _cl_context"""
class _cl_event( ctypes.Structure ):
    """Placeholder/empty structure for _cl_event"""
    
GLDEBUGPROCAMD = _p.DEFAULT_FUNCTION_TYPE(
    void,
    GLuint,# id,
    GLenum,# category,
    GLenum,# severity,
    GLsizei,# length,
    ctypes.c_char_p,# message,
    GLvoidp,# userParam
)

GLeglImageOES = GLvoidp 
c_int = ctypes.c_int




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_sync',error_checker=_errors._error_checker)
EGL_ALREADY_SIGNALED_NV=_C('EGL_ALREADY_SIGNALED_NV',0x30EA)
EGL_CONDITION_SATISFIED_NV=_C('EGL_CONDITION_SATISFIED_NV',0x30EC)
EGL_FOREVER_NV=_C('EGL_FOREVER_NV',0xFFFFFFFFFFFFFFFF)
# EGL_NO_SYNC_NV=_C('EGL_NO_SYNC_NV',((EGLSyncNV)0))
EGL_SIGNALED_NV=_C('EGL_SIGNALED_NV',0x30E8)
EGL_SYNC_CONDITION_NV=_C('EGL_SYNC_CONDITION_NV',0x30EE)
EGL_SYNC_FENCE_NV=_C('EGL_SYNC_FENCE_NV',0x30EF)
EGL_SYNC_FLUSH_COMMANDS_BIT_NV=_C('EGL_SYNC_FLUSH_COMMANDS_BIT_NV',0x0001)
EGL_SYNC_PRIOR_COMMANDS_COMPLETE_NV=_C('EGL_SYNC_PRIOR_COMMANDS_COMPLETE_NV',0x30E6)
EGL_SYNC_STATUS_NV=_C('EGL_SYNC_STATUS_NV',0x30E7)
EGL_SYNC_TYPE_NV=_C('EGL_SYNC_TYPE_NV',0x30ED)
EGL_TIMEOUT_EXPIRED_NV=_C('EGL_TIMEOUT_EXPIRED_NV',0x30EB)
EGL_UNSIGNALED_NV=_C('EGL_UNSIGNALED_NV',0x30E9)
@_f
@_p.types(_cs.EGLint,_cs.EGLSyncNV,_cs.EGLint,_cs.EGLTimeNV)
def eglClientWaitSyncNV(sync,flags,timeout):pass
@_f
@_p.types(_cs.EGLSyncNV,_cs.EGLDisplay,_cs.EGLenum,arrays.GLintArray)
def eglCreateFenceSyncNV(dpy,condition,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLSyncNV)
def eglDestroySyncNV(sync):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLSyncNV)
def eglFenceNV(sync):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLSyncNV,_cs.EGLint,arrays.GLintArray)
def eglGetSyncAttribNV(sync,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLSyncNV,_cs.EGLenum)
def eglSignalSyncNV(sync,mode):pass



'''OpenGL extension ANGLE.depth_texture

This module customises the behaviour of the 
OpenGL.raw.GLES2.ANGLE.depth_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines support for 2D depth and depth-stencil
	textures in an OpenGL ES implementation.
	
	This extension incorporates the depth texturing functionality of
	OES_depth_texture and OES_packed_depth_stencil, but does not
	provide the ability to load existing data via TexImage2D or
	TexSubImage2D. This extension also allows implementation
	variability in which components from a sampled depth texture
	contain the depth data. Depth textures created with this
	extension only support 1 level.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ANGLE/depth_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ANGLE.depth_texture import *
from OpenGL.raw.GLES2.ANGLE.depth_texture import _EXTENSION_NAME

def glInitDepthTextureANGLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.framebuffer_mixed_samples

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.framebuffer_mixed_samples to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows multisample rendering with a raster and
	depth/stencil sample count that is larger than the color sample count.
	Rasterization and the results of the depth and stencil tests together
	determine the portion of a pixel that is "covered".  It can be useful to
	evaluate coverage at a higher frequency than color samples are stored.
	This coverage is then "reduced" to a collection of covered color samples,
	each having an opacity value corresponding to the fraction of the color
	sample covered.  The opacity can optionally be blended into individual
	color samples.
	
	In the current hardware incarnation both depth and stencil testing are
	supported with mixed samples, although the API accommodates supporting
	only one or the other.
	
	Rendering with fewer color samples than depth/stencil samples can greatly
	reduce the amount of memory and bandwidth consumed by the color buffer.
	However, converting the coverage values into opacity can introduce
	artifacts where triangles share edges and may not be suitable for normal
	triangle mesh rendering.
	
	One expected use case for this functionality is Stencil-then-Cover path
	rendering (NV_path_rendering).  The stencil step determines the coverage
	(in the stencil buffer) for an entire path at the higher sample frequency,
	and then the cover step can draw the path into the lower frequency color
	buffer using the coverage information to antialias path edges. With this
	two-step process, internal edges are fully covered when antialiasing is
	applied and there is no corruption on these edges.
	
	The key features of this extension are:
	
	- It allows a framebuffer object to be considered complete when its depth
	  or stencil samples are a multiple of the number of color samples.
	
	- It redefines SAMPLES to be the number of depth/stencil samples (if any);
	  otherwise, it uses the number of color samples. SAMPLE_BUFFERS is one if
	  there are multisample depth/stencil attachments.  Multisample
	  rasterization and multisample fragment ops are allowed if SAMPLE_BUFFERS
	  is one.
	
	- It replaces several error checks involving SAMPLE_BUFFERS by error
	  checks directly referencing the number of samples in the relevant
	  attachments.
	
	- A coverage reduction step is added to Per-Fragment Operations which
	  converts a set of covered raster/depth/stencil samples to a set of
	  covered color samples.  The coverage reduction step also includes an
	  optional coverage modulation step, multiplying color values by a
	  fractional opacity corresponding to the number of associated
	  raster/depth/stencil samples covered.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/framebuffer_mixed_samples.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.framebuffer_mixed_samples import *
from OpenGL.raw.GLES2.NV.framebuffer_mixed_samples import _EXTENSION_NAME

def glInitFramebufferMixedSamplesNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glCoverageModulationTableNV.v size not checked against n
glCoverageModulationTableNV=wrapper.wrapper(glCoverageModulationTableNV).setInputArraySize(
    'v', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARM.mali_shader_binary

This module customises the behaviour of the 
OpenGL.raw.GLES2.ARM.mali_shader_binary to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables OpenGL ES 2.0 applications running on ARM
	Mali graphics cores to use shaders precompiled with the Mali ESSL
	shader compiler.
	
	The shader objects loaded with this extension are equivalent to
	shaders created from source, i.e. there are no additional
	restrictions on which other shader objects they can be linked to,
	nor on which OpenGL ES states they can be used with.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARM/mali_shader_binary.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ARM.mali_shader_binary import *
from OpenGL.raw.GLES2.ARM.mali_shader_binary import _EXTENSION_NAME

def glInitMaliShaderBinaryARM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.blend_equation_separate

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.blend_equation_separate to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES 1.1 provides a single blend equation that applies to both RGB
	and alpha portions of blending.  This extension provides a separate blend 
	equation for RGB and alpha to match the generality available for blend 
	factors.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/blend_equation_separate.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.blend_equation_separate import *
from OpenGL.raw.GLES1.OES.blend_equation_separate import _EXTENSION_NAME

def glInitBlendEquationSeparateOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension IMG.framebuffer_downsample

This module customises the behaviour of the 
OpenGL.raw.GLES2.IMG.framebuffer_downsample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces the ability to attach color buffers to a
	framebuffer that are at a lower resolution than the framebuffer itself, with
	the GPU automatically downsampling the color attachment to fit.
	
	This can be useful for various post-process rendering techniques where it is
	desirable to generate downsampled images in an efficient manner, or for a
	lower resolution post-process technique.
	
	This extension exposes at least a 2 x 2 downscale. Other downsampling modes
	may be exposed on the system and this can be queried.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IMG/framebuffer_downsample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.IMG.framebuffer_downsample import *
from OpenGL.raw.GLES2.IMG.framebuffer_downsample import _EXTENSION_NAME

def glInitFramebufferDownsampleIMG():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_semaphore_win32'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_semaphore_win32',error_checker=_errors._error_checker)
GL_D3D12_FENCE_VALUE_EXT=_C('GL_D3D12_FENCE_VALUE_EXT',0x9595)
GL_DEVICE_LUID_EXT=_C('GL_DEVICE_LUID_EXT',0x9599)
GL_DEVICE_NODE_MASK_EXT=_C('GL_DEVICE_NODE_MASK_EXT',0x959A)
GL_HANDLE_TYPE_D3D12_FENCE_EXT=_C('GL_HANDLE_TYPE_D3D12_FENCE_EXT',0x9594)
GL_HANDLE_TYPE_OPAQUE_WIN32_EXT=_C('GL_HANDLE_TYPE_OPAQUE_WIN32_EXT',0x9587)
GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT=_C('GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT',0x9588)
GL_LUID_SIZE_EXT=_C('GL_LUID_SIZE_EXT',8)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,ctypes.c_void_p)
def glImportSemaphoreWin32HandleEXT(semaphore,handleType,handle):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,ctypes.c_void_p)
def glImportSemaphoreWin32NameEXT(semaphore,handleType,name):pass



'''OpenGL extension EXT.texture_border_clamp

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.texture_border_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES provides only a single clamping wrap mode: CLAMP_TO_EDGE.
	However, the ability to clamp to a constant border color can be
	useful to quickly detect texture coordinates that exceed their
	expected limits or to dummy out any such accesses with transparency
	or a neutral color in tiling or light maps.
	
	This extension defines an additional texture clamping algorithm.
	CLAMP_TO_BORDER_EXT clamps texture coordinates at all mipmap levels
	such that NEAREST and LINEAR filters of clamped coordinates return
	only the constant border color. This does not add the ability for
	textures to specify borders using glTexImage2D, but only to clamp
	to a constant border value set using glTexParameter and
	glSamplerParameter.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_border_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.texture_border_clamp import *
from OpenGL.raw.GLES2.EXT.texture_border_clamp import _EXTENSION_NAME

def glInitTextureBorderClampEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexParameterIivEXT.params size not checked against 'pname'
glTexParameterIivEXT=wrapper.wrapper(glTexParameterIivEXT).setInputArraySize(
    'params', None
)
# INPUT glTexParameterIuivEXT.params size not checked against 'pname'
glTexParameterIuivEXT=wrapper.wrapper(glTexParameterIuivEXT).setInputArraySize(
    'params', None
)
glGetTexParameterIivEXT=wrapper.wrapper(glGetTexParameterIivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexParameterIuivEXT=wrapper.wrapper(glGetTexParameterIuivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glSamplerParameterIivEXT.param size not checked against 'pname'
glSamplerParameterIivEXT=wrapper.wrapper(glSamplerParameterIivEXT).setInputArraySize(
    'param', None
)
# INPUT glSamplerParameterIuivEXT.param size not checked against 'pname'
glSamplerParameterIuivEXT=wrapper.wrapper(glSamplerParameterIuivEXT).setInputArraySize(
    'param', None
)
# INPUT glGetSamplerParameterIivEXT.params size not checked against 'pname'
glGetSamplerParameterIivEXT=wrapper.wrapper(glGetSamplerParameterIivEXT).setInputArraySize(
    'params', None
)
# INPUT glGetSamplerParameterIuivEXT.params size not checked against 'pname'
glGetSamplerParameterIuivEXT=wrapper.wrapper(glGetSamplerParameterIuivEXT).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.shader_atomic_float64

This module customises the behaviour of the 
OpenGL.raw.GL.NV.shader_atomic_float64 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides GLSL built-in functions and assembly opcodes
	allowing shaders to perform atomic read-modify-write operations to buffer
	or shared memory with double-precision floating-point components.  The set
	of atomic operations provided by this extension is limited to adds and
	exchanges. Providing atomic add support allows shaders to atomically
	accumulate the sum of double-precision floating-point values into buffer
	memory across multiple (possibly concurrent) shader invocations.
	
	This extension provides GLSL support for atomics targeting double-precision
	floating-point pointers (if NV_gpu_shader5 is supported).
	Additionally, assembly opcodes for these operations are also provided if
	NV_gpu_program5 is supported.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shader_atomic_float64.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.shader_atomic_float64 import *
from OpenGL.raw.GL.NV.shader_atomic_float64 import _EXTENSION_NAME

def glInitShaderAtomicFloat64NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_4_1

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_4_1 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_4_1.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_4_1 import *
from OpenGL.raw.GL.VERSION.GL_4_1 import _EXTENSION_NAME

def glInitGl41VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glShaderBinary.binary size not checked against length
# INPUT glShaderBinary.shaders size not checked against count
glShaderBinary=wrapper.wrapper(glShaderBinary).setInputArraySize(
    'binary', None
).setInputArraySize(
    'shaders', None
)
glGetShaderPrecisionFormat=wrapper.wrapper(glGetShaderPrecisionFormat).setOutput(
    'precision',size=(1,),orPassIn=True
).setOutput(
    'range',size=(2,),orPassIn=True
)
glGetProgramBinary=wrapper.wrapper(glGetProgramBinary).setOutput(
    'binary',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'binaryFormat',size=(1,),orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
# INPUT glProgramBinary.binary size not checked against length
glProgramBinary=wrapper.wrapper(glProgramBinary).setInputArraySize(
    'binary', None
)
# INPUT glCreateShaderProgramv.strings size not checked against count
glCreateShaderProgramv=wrapper.wrapper(glCreateShaderProgramv).setInputArraySize(
    'strings', None
)
# INPUT glDeleteProgramPipelines.pipelines size not checked against n
glDeleteProgramPipelines=wrapper.wrapper(glDeleteProgramPipelines).setInputArraySize(
    'pipelines', None
)
glGenProgramPipelines=wrapper.wrapper(glGenProgramPipelines).setOutput(
    'pipelines',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetProgramPipelineiv=wrapper.wrapper(glGetProgramPipelineiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glProgramUniform1iv.value size not checked against count
glProgramUniform1iv=wrapper.wrapper(glProgramUniform1iv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform1fv.value size not checked against count
glProgramUniform1fv=wrapper.wrapper(glProgramUniform1fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform1dv.value size not checked against count
glProgramUniform1dv=wrapper.wrapper(glProgramUniform1dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform1uiv.value size not checked against count
glProgramUniform1uiv=wrapper.wrapper(glProgramUniform1uiv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2iv.value size not checked against count*2
glProgramUniform2iv=wrapper.wrapper(glProgramUniform2iv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2fv.value size not checked against count*2
glProgramUniform2fv=wrapper.wrapper(glProgramUniform2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2dv.value size not checked against count*2
glProgramUniform2dv=wrapper.wrapper(glProgramUniform2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2uiv.value size not checked against count*2
glProgramUniform2uiv=wrapper.wrapper(glProgramUniform2uiv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3iv.value size not checked against count*3
glProgramUniform3iv=wrapper.wrapper(glProgramUniform3iv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3fv.value size not checked against count*3
glProgramUniform3fv=wrapper.wrapper(glProgramUniform3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3dv.value size not checked against count*3
glProgramUniform3dv=wrapper.wrapper(glProgramUniform3dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3uiv.value size not checked against count*3
glProgramUniform3uiv=wrapper.wrapper(glProgramUniform3uiv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4iv.value size not checked against count*4
glProgramUniform4iv=wrapper.wrapper(glProgramUniform4iv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4fv.value size not checked against count*4
glProgramUniform4fv=wrapper.wrapper(glProgramUniform4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4dv.value size not checked against count*4
glProgramUniform4dv=wrapper.wrapper(glProgramUniform4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4uiv.value size not checked against count*4
glProgramUniform4uiv=wrapper.wrapper(glProgramUniform4uiv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2fv.value size not checked against count*4
glProgramUniformMatrix2fv=wrapper.wrapper(glProgramUniformMatrix2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3fv.value size not checked against count*9
glProgramUniformMatrix3fv=wrapper.wrapper(glProgramUniformMatrix3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4fv.value size not checked against count*16
glProgramUniformMatrix4fv=wrapper.wrapper(glProgramUniformMatrix4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2dv.value size not checked against count*4
glProgramUniformMatrix2dv=wrapper.wrapper(glProgramUniformMatrix2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3dv.value size not checked against count*9
glProgramUniformMatrix3dv=wrapper.wrapper(glProgramUniformMatrix3dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4dv.value size not checked against count*16
glProgramUniformMatrix4dv=wrapper.wrapper(glProgramUniformMatrix4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x3fv.value size not checked against count*6
glProgramUniformMatrix2x3fv=wrapper.wrapper(glProgramUniformMatrix2x3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x2fv.value size not checked against count*6
glProgramUniformMatrix3x2fv=wrapper.wrapper(glProgramUniformMatrix3x2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x4fv.value size not checked against count*8
glProgramUniformMatrix2x4fv=wrapper.wrapper(glProgramUniformMatrix2x4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x2fv.value size not checked against count*8
glProgramUniformMatrix4x2fv=wrapper.wrapper(glProgramUniformMatrix4x2fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x4fv.value size not checked against count*12
glProgramUniformMatrix3x4fv=wrapper.wrapper(glProgramUniformMatrix3x4fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x3fv.value size not checked against count*12
glProgramUniformMatrix4x3fv=wrapper.wrapper(glProgramUniformMatrix4x3fv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x3dv.value size not checked against count*6
glProgramUniformMatrix2x3dv=wrapper.wrapper(glProgramUniformMatrix2x3dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x2dv.value size not checked against count*6
glProgramUniformMatrix3x2dv=wrapper.wrapper(glProgramUniformMatrix3x2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix2x4dv.value size not checked against count*8
glProgramUniformMatrix2x4dv=wrapper.wrapper(glProgramUniformMatrix2x4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x2dv.value size not checked against count*8
glProgramUniformMatrix4x2dv=wrapper.wrapper(glProgramUniformMatrix4x2dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix3x4dv.value size not checked against count*12
glProgramUniformMatrix3x4dv=wrapper.wrapper(glProgramUniformMatrix3x4dv).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformMatrix4x3dv.value size not checked against count*12
glProgramUniformMatrix4x3dv=wrapper.wrapper(glProgramUniformMatrix4x3dv).setInputArraySize(
    'value', None
)
glGetProgramPipelineInfoLog=wrapper.wrapper(glGetProgramPipelineInfoLog).setOutput(
    'infoLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
glVertexAttribL1dv=wrapper.wrapper(glVertexAttribL1dv).setInputArraySize(
    'v', 1
)
glVertexAttribL2dv=wrapper.wrapper(glVertexAttribL2dv).setInputArraySize(
    'v', 2
)
glVertexAttribL3dv=wrapper.wrapper(glVertexAttribL3dv).setInputArraySize(
    'v', 3
)
glVertexAttribL4dv=wrapper.wrapper(glVertexAttribL4dv).setInputArraySize(
    'v', 4
)
# INPUT glVertexAttribLPointer.pointer size not checked against size
glVertexAttribLPointer=wrapper.wrapper(glVertexAttribLPointer).setInputArraySize(
    'pointer', None
)
glGetVertexAttribLdv=wrapper.wrapper(glGetVertexAttribLdv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glViewportArrayv.v size not checked against 'count'
glViewportArrayv=wrapper.wrapper(glViewportArrayv).setInputArraySize(
    'v', None
)
glViewportIndexedfv=wrapper.wrapper(glViewportIndexedfv).setInputArraySize(
    'v', 4
)
# INPUT glScissorArrayv.v size not checked against 'count'
glScissorArrayv=wrapper.wrapper(glScissorArrayv).setInputArraySize(
    'v', None
)
glScissorIndexedv=wrapper.wrapper(glScissorIndexedv).setInputArraySize(
    'v', 4
)
# INPUT glDepthRangeArrayv.v size not checked against 'count'
glDepthRangeArrayv=wrapper.wrapper(glDepthRangeArrayv).setInputArraySize(
    'v', None
)
glGetFloati_v=wrapper.wrapper(glGetFloati_v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
glGetDoublei_v=wrapper.wrapper(glGetDoublei_v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
### END AUTOGENERATED SECTION
from OpenGL.GL.ARB.ES2_compatibility import *
from OpenGL.GL.ARB.get_program_binary import *
from OpenGL.GL.ARB.separate_shader_objects import *
from OpenGL.GL.ARB.shader_precision import *
from OpenGL.GL.ARB.vertex_attrib_64bit import *
from OpenGL.GL.ARB.viewport_array import *



'''OpenGL extension EXT.pvrtc_sRGB

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.pvrtc_sRGB to provide a more 
Python-friendly API

Overview (from the spec)
	
	The response from electronic display systems given RGB tristimulus values 
	for each pixel is non-linear.  Gamma correction is the process of encoding 
	or decoding images in a manner that will correct for non-linear response 
	profiles of output devices.  The displayed results of gamma-corrected pixel 
	data are more consistent and predictable for the author of such pixel data 
	than it would otherwise be with linearly encoded pixel data.
	
	This EXT_pvrtc_sRGB extension specifies additional tokens for gamma 
	corrected PVRTC compressed sRGB data.  
	
	Texture assets are developed and evaluated for use in OpenGL applications 
	using electronic displays with non-linear responses.  This extension 
	provides a better measure of consistency between textures developed within 
	an asset toolchain and their final rendered result with an OpenGL 
	application that uses those textures.
	
	Conventional OpenGL texture tristimulus values as well as their alpha 
	component are encoded linearly.  The textures introduced by this extension 
	are encoded with gamma correction in the tristimulus components but 
	linearly in the alpha component.
	
	When gamma corrected texture samples are fetched and operated on by ALU 
	operations in an OpenGL shading program those samples will be converted 
	from gamma corrected space to linear space for logical simplicity and 
	performance of the shader.
	
	Texture filtering operations as well as mipmap generation are carried out 
	in linear space.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/pvrtc_sRGB.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.pvrtc_sRGB import *
from OpenGL.raw.GLES2.EXT.pvrtc_sRGB import _EXTENSION_NAME

def glInitPvrtcSrgbEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.conservative_raster_dilate

This module customises the behaviour of the 
OpenGL.raw.GL.NV.conservative_raster_dilate to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the conservative rasterization functionality 
	provided by NV_conservative_raster. It provides a new control to generate 
	an "over-conservative" rasterization by dilating primitives prior to 
	rasterization.
	
	When using conservative raster to bin geometry, this extension provides a 
	programmable overlap region between adjacent primitives.  Regular 
	rasterization bins triangles with a shared edge uniquely into pixels. 
	Conservative raster has a one-pixel overlap along the shared edge.  Using 
	a half-pixel raster dilation, this overlap region increases to two pixels.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/conservative_raster_dilate.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.conservative_raster_dilate import *
from OpenGL.raw.GL.NV.conservative_raster_dilate import _EXTENSION_NAME

def glInitConservativeRasterDilateNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.framebuffer_multisample_blit_scaled

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.framebuffer_multisample_blit_scaled to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension relaxes some of the restrictions associated with
	multisample resolve operations, specifically to allow a combined
	resolve and scale operation through a single call to BlitFramebuffer.
	It also adds two new filter types to control the quality of the
	combined scaled resolve operation.
	
	In traditional multisampled framebuffer rendering, color samples
	must be explicitly resolved via BlitFramebuffer before any other
	operation on the resulting pixel values can be performed.  This
	multisample resolve operation must be done using a BlitFramebuffer
	call where the dimensions of the source and destination rectangles
	are identical.  If the resulting pixel values need to be copied to a
	texture with different dimensions, these resolved values can then be
	scaled with a second call to BlitFramebuffer.
	
	By requiring two separate calls to BlitFramebuffer, the quality
	of final image can be maintained to a certain degree.  The samples
	are first resolved, and then these resolved values can be filtered
	to produce the final image.  This image quality comes at the price
	of increased memory usage and lower performance.  However, the
	scaling blit can still introduce artifacts, particularly if it is
	done with a simple bilinear filter.
	
	The new filter types introduced by this extension allow the scaled
	resolve to be done with a single call to BlitFramebuffer.  Not all
	samples from the read framebuffer are required to be be used when
	producing the final pixel values, and there may be a loss in quality
	when compared to an image produced by a separate resolve and scale.
	However, the single-pass scaled resolve blit should be faster than
	the traditional two-pass resolve then scale blits.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/framebuffer_multisample_blit_scaled.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.framebuffer_multisample_blit_scaled import *
from OpenGL.raw.GL.EXT.framebuffer_multisample_blit_scaled import _EXTENSION_NAME

def glInitFramebufferMultisampleBlitScaledEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_matrix_palette'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_matrix_palette',error_checker=_errors._error_checker)
GL_CURRENT_PALETTE_MATRIX_OES=_C('GL_CURRENT_PALETTE_MATRIX_OES',0x8843)
GL_MATRIX_INDEX_ARRAY_BUFFER_BINDING_OES=_C('GL_MATRIX_INDEX_ARRAY_BUFFER_BINDING_OES',0x8B9E)
GL_MATRIX_INDEX_ARRAY_OES=_C('GL_MATRIX_INDEX_ARRAY_OES',0x8844)
GL_MATRIX_INDEX_ARRAY_POINTER_OES=_C('GL_MATRIX_INDEX_ARRAY_POINTER_OES',0x8849)
GL_MATRIX_INDEX_ARRAY_SIZE_OES=_C('GL_MATRIX_INDEX_ARRAY_SIZE_OES',0x8846)
GL_MATRIX_INDEX_ARRAY_STRIDE_OES=_C('GL_MATRIX_INDEX_ARRAY_STRIDE_OES',0x8848)
GL_MATRIX_INDEX_ARRAY_TYPE_OES=_C('GL_MATRIX_INDEX_ARRAY_TYPE_OES',0x8847)
GL_MATRIX_PALETTE_OES=_C('GL_MATRIX_PALETTE_OES',0x8840)
GL_MAX_PALETTE_MATRICES_OES=_C('GL_MAX_PALETTE_MATRICES_OES',0x8842)
GL_MAX_VERTEX_UNITS_OES=_C('GL_MAX_VERTEX_UNITS_OES',0x86A4)
GL_WEIGHT_ARRAY_BUFFER_BINDING_OES=_C('GL_WEIGHT_ARRAY_BUFFER_BINDING_OES',0x889E)
GL_WEIGHT_ARRAY_OES=_C('GL_WEIGHT_ARRAY_OES',0x86AD)
GL_WEIGHT_ARRAY_POINTER_OES=_C('GL_WEIGHT_ARRAY_POINTER_OES',0x86AC)
GL_WEIGHT_ARRAY_SIZE_OES=_C('GL_WEIGHT_ARRAY_SIZE_OES',0x86AB)
GL_WEIGHT_ARRAY_STRIDE_OES=_C('GL_WEIGHT_ARRAY_STRIDE_OES',0x86AA)
GL_WEIGHT_ARRAY_TYPE_OES=_C('GL_WEIGHT_ARRAY_TYPE_OES',0x86A9)
@_f
@_p.types(None,_cs.GLuint)
def glCurrentPaletteMatrixOES(matrixpaletteindex):pass
@_f
@_p.types(None,)
def glLoadPaletteFromModelViewMatrixOES():pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glMatrixIndexPointerOES(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glWeightPointerOES(size,type,stride,pointer):pass



'''OpenGL extension KHR.parallel_shader_compile

This module customises the behaviour of the 
OpenGL.raw.GLES2.KHR.parallel_shader_compile to provide a more 
Python-friendly API

Overview (from the spec)
	
	Compiling GLSL into implementation-specific code can be a time consuming
	process, so a GL implementation may wish to perform the compilation in a
	separate CPU thread. This extension provides a mechanism for the application
	to provide a hint to limit the number of threads it wants to be used to
	compile shaders, as well as a query to determine if the compilation process
	is complete.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/parallel_shader_compile.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.KHR.parallel_shader_compile import *
from OpenGL.raw.GLES2.KHR.parallel_shader_compile import _EXTENSION_NAME

def glInitParallelShaderCompileKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.texture_3D

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.texture_3D to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for 3D textures.  The OpenGL ES 2.0 texture wrap
	modes and mip-mapping is supported for power of two 3D textures.  Mip-
	mapping and texture wrap modes other than CLAMP_TO_EDGE are not supported 
	for non-power of two 3D textures.
	
	The OES_texture_npot extension, if supported, will enable mip-mapping and 
	other wrap modes for non-power of two 3D textures.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_3D.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.texture_3D import *
from OpenGL.raw.GLES2.OES.texture_3D import _EXTENSION_NAME

def glInitTexture3DOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexImage3DOES.pixels size not checked against 'format,type,width,height,depth'
glTexImage3DOES=wrapper.wrapper(glTexImage3DOES).setInputArraySize(
    'pixels', None
)
# INPUT glTexSubImage3DOES.pixels size not checked against 'format,type,width,height,depth'
glTexSubImage3DOES=wrapper.wrapper(glTexSubImage3DOES).setInputArraySize(
    'pixels', None
)
# INPUT glCompressedTexImage3DOES.data size not checked against imageSize
glCompressedTexImage3DOES=wrapper.wrapper(glCompressedTexImage3DOES).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage3DOES.data size not checked against imageSize
glCompressedTexSubImage3DOES=wrapper.wrapper(glCompressedTexSubImage3DOES).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.copy_buffer

This module customises the behaviour of the 
OpenGL.raw.GLX.NV.copy_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to do an accelerated copy from one
	buffer object to another. This may be useful to load buffer objects
	in a "loading thread" while minimizing cost and synchronization effort
	in the "rendering thread."

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/copy_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.NV.copy_buffer import *
from OpenGL.raw.GLX.NV.copy_buffer import _EXTENSION_NAME

def glInitCopyBufferNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.query_resource_tag

This module customises the behaviour of the 
OpenGL.raw.GL.NV.query_resource_tag to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the capability to associate a tag with one or more
	memory resource allocations. This tag can be reported back during
	queryResource operations and also be used to limit resource reporting to
	only those allocations with the specified tag. A tag is a previously
	reserved id and an optional text string.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/query_resource_tag.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.query_resource_tag import *
from OpenGL.raw.GL.NV.query_resource_tag import _EXTENSION_NAME

def glInitQueryResourceTagNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGenQueryResourceTagNV.tagIds size not checked against n
glGenQueryResourceTagNV=wrapper.wrapper(glGenQueryResourceTagNV).setInputArraySize(
    'tagIds', None
)
# INPUT glDeleteQueryResourceTagNV.tagIds size not checked against n
glDeleteQueryResourceTagNV=wrapper.wrapper(glDeleteQueryResourceTagNV).setInputArraySize(
    'tagIds', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.discard_framebuffer

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.discard_framebuffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new command, DiscardFramebufferEXT, which 
	causes the contents of the named framebuffer attachable images to become 
	undefined.  The contents of the specified buffers are undefined until a 
	subsequent operation modifies the content, and only the modified region 
	is guaranteed to hold valid content.  Effective usage of this command 
	may provide an implementation with new optimization opportunities.
	
	Some OpenGL ES implementations cache framebuffer images in a small pool 
	of fast memory.  Before rendering, these implementations must load the
	existing contents of one or more of the logical buffers (color, depth, 
	stencil, etc.) into this memory.  After rendering, some or all of these 
	buffers are likewise stored back to external memory so their contents can
	be used again in the future.  In many applications, some or all of the 
	logical buffers  are cleared at the start of rendering.  If so, the 
	effort to load or store those buffers is wasted.
	
	Even without this extension, if a frame of rendering begins with a full-
	screen Clear, an OpenGL ES implementation may optimize away the loading
	of framebuffer contents prior to rendering the frame.  With this extension, 
	an application can use DiscardFramebufferEXT to signal that framebuffer 
	contents will no longer be needed.  In this case an OpenGL ES 
	implementation may also optimize away the storing back of framebuffer 
	contents after rendering the frame.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/discard_framebuffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.discard_framebuffer import *
from OpenGL.raw.GLES2.EXT.discard_framebuffer import _EXTENSION_NAME

def glInitDiscardFramebufferEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDiscardFramebufferEXT.attachments size not checked against numAttachments
glDiscardFramebufferEXT=wrapper.wrapper(glDiscardFramebufferEXT).setInputArraySize(
    'attachments', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension AMD.framebuffer_sample_positions

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.framebuffer_sample_positions to provide a more 
Python-friendly API

Overview (from the spec)
	
	In unextended GL, the sub-pixel loations of multisampled textures and
	renderbuffers are generally determined in an implementation dependent
	manner. Some algorithms -- in particular custom antialiasing functions --
	depend on the knowledge of, or even require control over the positions of
	samples within each pixel.
	
	The AMD_sample_positions extension added some control over the positions
	of samples within a single framebuffer. However, it forced all pixels
	within a framebuffer to have the set of sample positions.
	
	This extension provides a mechanism to explicitly set sample positions for
	a framebuffer object with multi-sampled attachments in a repeating pattern,
	allowing different pixels to use different sub-pixel locations for their
	samples. The sample locations used by the FBO can be fixed for all pixels
	in the FBOs attachments or they can be fixed for a sampling pattern
	comprised of multiple pixels, where the sampling pattern is repeated over
	all pixels. The rate of repeat of this sampling pattern size itself is
	fixed and is implementation-dependent.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/framebuffer_sample_positions.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.framebuffer_sample_positions import *
from OpenGL.raw.GL.AMD.framebuffer_sample_positions import _EXTENSION_NAME

def glInitFramebufferSamplePositionsAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.element_array

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.element_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides facilities to improve DrawElements style vertex
	indices submission performance by allowing index arrays.  Using this
	extension these arrays can be contained inside a vertex array range and
	thus pulled directly by the graphics processor, avoiding the CPU overhead
	of touching the index data.
	
	This extension is most useful when used in conjunction with the
	APPLE_vertex_array_range extension. APPLE_vertex_array_range provides an
	interface for storing vertex array data. In cases where large amounts of
	vertex data are in use, the index data used to construct primitives
	(typically as passed to the GL through DrawElements) can impose a
	significant bandwidth burden. APPLE_element_array allows the application to
	specify independent arrays of elements, which can then be cached using
	APPLE_vertex_array_range.  In effect this creates a more orthogonal
	interface for both vertex indices and data.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/element_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.element_array import *
from OpenGL.raw.GL.APPLE.element_array import _EXTENSION_NAME

def glInitElementArrayAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glElementPointerAPPLE.pointer size not checked against 'type'
glElementPointerAPPLE=wrapper.wrapper(glElementPointerAPPLE).setInputArraySize(
    'pointer', None
)
# INPUT glMultiDrawElementArrayAPPLE.count size not checked against primcount
# INPUT glMultiDrawElementArrayAPPLE.first size not checked against primcount
glMultiDrawElementArrayAPPLE=wrapper.wrapper(glMultiDrawElementArrayAPPLE).setInputArraySize(
    'count', None
).setInputArraySize(
    'first', None
)
# INPUT glMultiDrawRangeElementArrayAPPLE.count size not checked against primcount
# INPUT glMultiDrawRangeElementArrayAPPLE.first size not checked against primcount
glMultiDrawRangeElementArrayAPPLE=wrapper.wrapper(glMultiDrawRangeElementArrayAPPLE).setInputArraySize(
    'count', None
).setInputArraySize(
    'first', None
)
### END AUTOGENERATED SECTION



'''OpenGL extension ARB.matrix_palette

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.matrix_palette to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the abilities of ARB_vertex_blend to include 
	a palette of modelview matrices.  The n vertex units use a palette
	of m modelview matrices.  (Where n and m are constrained to
	implementation defined maxima.)  Each vertex has a set of n
	indices into the palette, and a corresponding set of n weights.
	Matrix indices can be changed for each vertex (between Begin and
	End).  
	
	When this extension is utilized, the enabled units transform each
	vertex by the modelview matrices specified by the vertices'
	respective indices.  These results are subsequently scaled by the
	weights of the respective units and then summed to create the
	eyespace vertex.   
	
	A similar procedure is followed for normals.  Normals, however,
	are transformed by the inverse transpose of the modelview matrix.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/matrix_palette.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.matrix_palette import *
from OpenGL.raw.GL.ARB.matrix_palette import _EXTENSION_NAME

def glInitMatrixPaletteARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glMatrixIndexubvARB.indices size not checked against size
glMatrixIndexubvARB=wrapper.wrapper(glMatrixIndexubvARB).setInputArraySize(
    'indices', None
)
# INPUT glMatrixIndexusvARB.indices size not checked against size
glMatrixIndexusvARB=wrapper.wrapper(glMatrixIndexusvARB).setInputArraySize(
    'indices', None
)
# INPUT glMatrixIndexuivARB.indices size not checked against size
glMatrixIndexuivARB=wrapper.wrapper(glMatrixIndexuivARB).setInputArraySize(
    'indices', None
)
# INPUT glMatrixIndexPointerARB.pointer size not checked against 'size,type,stride'
glMatrixIndexPointerARB=wrapper.wrapper(glMatrixIndexPointerARB).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_clip_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_clip_control',error_checker=_errors._error_checker)
GL_CLIP_DEPTH_MODE_EXT=_C('GL_CLIP_DEPTH_MODE_EXT',0x935D)
GL_CLIP_ORIGIN_EXT=_C('GL_CLIP_ORIGIN_EXT',0x935C)
GL_LOWER_LEFT_EXT=_C('GL_LOWER_LEFT_EXT',0x8CA1)
GL_NEGATIVE_ONE_TO_ONE_EXT=_C('GL_NEGATIVE_ONE_TO_ONE_EXT',0x935E)
GL_UPPER_LEFT_EXT=_C('GL_UPPER_LEFT_EXT',0x8CA2)
GL_ZERO_TO_ONE_EXT=_C('GL_ZERO_TO_ONE_EXT',0x935F)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glClipControlEXT(origin,depth):pass



'''OpenGL extension ARB.ES3_2_compatibility

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.ES3_2_compatibility to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for features of OpenGL ES 3.2 that are
	missing from OpenGL 4.5. Enabling these features will ease the process
	of porting applications from OpenGL ES 3.2 to OpenGL.
	
	In particular this adds the following features:
	
	- Bounding box used to optimization tessellation processing
	  (OES_primitive_bounding_box)
	- query for MULTISAMPLE_LINE_WIDTH_RANGE_ARB
	- support for the OpenGL ES 3.20 shading language
	
	For full OpenGL ES 3.2 compatibility the implementation must support
	KHR_blend_equation_advanced and KHR_texture_compression_astc_ldr. Those
	features are not defined in this extension spec since they are already
	defined at the KHR level.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/ES3_2_compatibility.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.ES3_2_compatibility import *
from OpenGL.raw.GL.ARB.ES3_2_compatibility import _EXTENSION_NAME

def glInitEs32CompatibilityARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_raster_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_raster_multisample',error_checker=_errors._error_checker)
GL_EFFECTIVE_RASTER_SAMPLES_EXT=_C('GL_EFFECTIVE_RASTER_SAMPLES_EXT',0x932C)
GL_MAX_RASTER_SAMPLES_EXT=_C('GL_MAX_RASTER_SAMPLES_EXT',0x9329)
GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT=_C('GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT',0x932B)
GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT=_C('GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT',0x932A)
GL_RASTER_MULTISAMPLE_EXT=_C('GL_RASTER_MULTISAMPLE_EXT',0x9327)
GL_RASTER_SAMPLES_EXT=_C('GL_RASTER_SAMPLES_EXT',0x9328)
@_f
@_p.types(None,_cs.GLuint,_cs.GLboolean)
def glRasterSamplesEXT(samples,fixedsamplelocations):pass



'''OpenGL extension VERSION.GL_4_0

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_4_0 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_4_0.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_4_0 import *
from OpenGL.raw.GL.VERSION.GL_4_0 import _EXTENSION_NAME

def glInitGl40VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniform1dv.value size not checked against count
glUniform1dv=wrapper.wrapper(glUniform1dv).setInputArraySize(
    'value', None
)
# INPUT glUniform2dv.value size not checked against count*2
glUniform2dv=wrapper.wrapper(glUniform2dv).setInputArraySize(
    'value', None
)
# INPUT glUniform3dv.value size not checked against count*3
glUniform3dv=wrapper.wrapper(glUniform3dv).setInputArraySize(
    'value', None
)
# INPUT glUniform4dv.value size not checked against count*4
glUniform4dv=wrapper.wrapper(glUniform4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2dv.value size not checked against count*4
glUniformMatrix2dv=wrapper.wrapper(glUniformMatrix2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3dv.value size not checked against count*9
glUniformMatrix3dv=wrapper.wrapper(glUniformMatrix3dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4dv.value size not checked against count*16
glUniformMatrix4dv=wrapper.wrapper(glUniformMatrix4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x3dv.value size not checked against count*6
glUniformMatrix2x3dv=wrapper.wrapper(glUniformMatrix2x3dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x4dv.value size not checked against count*8
glUniformMatrix2x4dv=wrapper.wrapper(glUniformMatrix2x4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x2dv.value size not checked against count*6
glUniformMatrix3x2dv=wrapper.wrapper(glUniformMatrix3x2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x4dv.value size not checked against count*12
glUniformMatrix3x4dv=wrapper.wrapper(glUniformMatrix3x4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x2dv.value size not checked against count*8
glUniformMatrix4x2dv=wrapper.wrapper(glUniformMatrix4x2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x3dv.value size not checked against count*12
glUniformMatrix4x3dv=wrapper.wrapper(glUniformMatrix4x3dv).setInputArraySize(
    'value', None
)
# OUTPUT glGetUniformdv.params COMPSIZE(program, location) 
glGetActiveSubroutineUniformiv=wrapper.wrapper(glGetActiveSubroutineUniformiv).setOutput(
    'values',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetActiveSubroutineUniformName=wrapper.wrapper(glGetActiveSubroutineUniformName).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufsize',orPassIn=True
)
glGetActiveSubroutineName=wrapper.wrapper(glGetActiveSubroutineName).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufsize',orPassIn=True
)
# INPUT glUniformSubroutinesuiv.indices size not checked against count
glUniformSubroutinesuiv=wrapper.wrapper(glUniformSubroutinesuiv).setInputArraySize(
    'indices', None
)
glGetUniformSubroutineuiv=wrapper.wrapper(glGetUniformSubroutineuiv).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetProgramStageiv=wrapper.wrapper(glGetProgramStageiv).setOutput(
    'values',size=(1,),orPassIn=True
)
# INPUT glPatchParameterfv.values size not checked against 'pname'
glPatchParameterfv=wrapper.wrapper(glPatchParameterfv).setInputArraySize(
    'values', None
)
# INPUT glDeleteTransformFeedbacks.ids size not checked against n
glDeleteTransformFeedbacks=wrapper.wrapper(glDeleteTransformFeedbacks).setInputArraySize(
    'ids', None
)
glGenTransformFeedbacks=wrapper.wrapper(glGenTransformFeedbacks).setOutput(
    'ids',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetQueryIndexediv=wrapper.wrapper(glGetQueryIndexediv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION



'''OpenGL extension NV.internalformat_sample_query

This module customises the behaviour of the 
OpenGL.raw.GL.NV.internalformat_sample_query to provide a more 
Python-friendly API

Overview (from the spec)
	
	Some OpenGL implementations support modes of multisampling which have
	properties which are non-obvious to applications and/or which may not be
	standards conformant. The idea of non-conformant AA modes is not new,
	and is exposed in both GLX and EGL with config caveats and the
	GLX_NON_CONFORMANT_CONFIG for GLX and EGL_NON_CONFORMANT_CONFIG for EGL,
	or by querying the EGL_CONFORMANT attribute in newer versions of EGL.
	
	Both of these mechanisms operate on a per-config basis, which works as
	intended for window-based configs. However, with the advent of
	application-created FBOs, it is now possible to do all the multisample
	operations in an application-created FBO and never use a multisample
	window.
	
	This extension further extends the internalformat query mechanism
	(first introduced by ARB_internalformat_query and extended in
	ARB_internalformat_query2) and introduces a mechanism for a
	implementation to report properties of formats that may also be
	dependent on the number of samples.  This includes information
	such as whether the combination of format and samples should be
	considered conformant. This enables an implementation to report
	caveats which might apply to both window and FBO-based rendering
	configurations.
	
	Some NVIDIA drivers support multisample modes which are internally
	implemented as a combination of multisampling and automatic
	supersampling in order to obtain a higher level of anti-aliasing than
	can be directly supported by hardware. This extension allows those
	properties to be queried by an application with the MULTISAMPLES_NV,
	SUPERSAMPLE_SCALE_X_NV and SUPERSAMPLE_SCALE_Y_NV properties. For
	example, a 16xAA mode might be implemented by using 4 samples and
	up-scaling by a factor of 2 in each of the x- and y-dimensions.
	In this example, the driver might report MULTSAMPLES_NV of 4,
	SUPERSAMPLE_SCALE_X_NV of 2, SUPERSAMPLE_SCALE_Y_NV of 2 and
	CONFORMANT_NV of FALSE.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/internalformat_sample_query.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.internalformat_sample_query import *
from OpenGL.raw.GL.NV.internalformat_sample_query import _EXTENSION_NAME

def glInitInternalformatSampleQueryNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetInternalformatSampleivNV.params size not checked against bufSize
glGetInternalformatSampleivNV=wrapper.wrapper(glGetInternalformatSampleivNV).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_sRGB_R8

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.texture_sRGB_R8 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces SR8_EXT as an acceptable internal format.
	This allows efficient sRGB sampling for source images stored as a separate
	texture per channel.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_sRGB_R8.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.texture_sRGB_R8 import *
from OpenGL.raw.GLES2.EXT.texture_sRGB_R8 import _EXTENSION_NAME

def glInitTextureSrgbR8EXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.polygon_mode

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.polygon_mode to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a PolygonModeNV entry point which can be used to change
	the polygon rasterization method. Using this extension, state consistent
	with rendering triangle primitives can trivially be toggled to render
	primitives as lines or points. In addition, independent enables are
	provided for polygon offset in conjunction with these new point and line
	polygon modes.
	
	This introduces a level of support for PolygonMode comparable with the
	OpenGL 4.3 core profile.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/polygon_mode.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.polygon_mode import *
from OpenGL.raw.GLES2.NV.polygon_mode import _EXTENSION_NAME

def glInitPolygonModeNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.sRGB_formats

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.sRGB_formats to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds new uncompressed and compressed color texture
	formats with nonlinear sRGB color components.
	
	Luminance and luminance alpha provide support for textures
	containing sRGB values with identical red, green, and blue
	components.
	
	Compressed texture formats using S3TC and ETC1 compression
	algorithms are also added to provide compressed sRGB texture
	options.
	
	Finally, sized variant of sRGB, sLuminace, and sLuminance_alpha are
	provided for immutable textures defined using the EXT_texture_storage
	extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/sRGB_formats.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.sRGB_formats import *
from OpenGL.raw.GLES2.NV.sRGB_formats import _EXTENSION_NAME

def glInitSrgbFormatsNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.shared_multisample

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIS.shared_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	While the OpenGL multisample extension (SGIS_multisample) provides
	good out-of-order antialiasing via subpixel samples, multisample
	hardware is very expensive because it multiplies the per-pixel
	framebuffer memory required to maintain color, depth, and stencil
	state by the number of samples.
	
	The cost-sensitive Location Based Entertainment (LBE) market
	desires good quality antialiasing, but the cost of maintaining
	multisample memory for every pixel in the framebuffer managed area
	is often prohibitive.  Low-end multi-channel visual simulation may
	have similar cost constraints.
	
	LBE applications typically render several channels that are output
	to different video display devices.  For example, an LBE
	application may render four 800x600 resolution channels, one per
	game player.  While the total managed area may be 1600x1200, each
	channel ends up being rendered serially.  With traditional
	multisampling (as specified by SGIS_multisample), multisample
	memory must be retained across the entire 1600x1200 managed area
	though in fact the application is never using more than an 800x600
	rectangle of multisample pixel state at any given time.
	
	This sharing of multisample framebuffer state can result in a
	substantial competitive advantage for high-end multi-channel
	multisampling hardware for LBE applications.  Unlike a "cheap PC
	per seat" solution, a high-end solution can be amortized by sharing
	both texture and multisample memory between the multiple channels
	(as well as host resources such as disk and CPUs).  For cheap PCs
	to have the same amount of texture memory and quality of
	antialiasing, texture and multisample memory have to be replicated
	in every PC.
	
	In a typical windowed environment, the entire framebuffer managed
	area must retain multisample state because windows can be moved
	dynamically and resized (up to the entire size of the managed
	area).  For LBE applications though, the layout of channel
	subrectangles in the framebuffer managed area is static and the
	LBE application monopolizes the graphics device (no other
	concurrent windowed apps).  Because of their channel-oriented,
	dedicated, cost-sensitive nature, LBE applications can benefit from
	a means to share the available multisample memory resources among
	all the channels.
	
	The SGIS_shared_multisample extension specifies a single
	multisample buffer subrectangle sized smaller than the total
	managed area that is both shared among multiple windows and
	repositionable within in a window.
	
	Use of the SGIS_shared_multisample extension is predicated on
	specially configuring the window system, typically via a command
	line option added to the window system server's startup command.
	When run in this mode, OpenGL applications will see the
	GL_SGIS_shared_multisample string advertised in the GL_EXTENSIONS
	string (along with the GL_SGIS_multisample string).  In this mode,
	the behavior of multisample extension changes.  Instead of the
	multisample buffer memory being retained per-pixel across the
	entire managed area, multisample memory is shared among multisample
	windows and repositionable within a multisample window.
	
	Switching windows or repositioning the multisample subrectangle
	will make undefined the shared state within the multisample, depth,
	stencil, and accumulation buffers.
	
	When rendering into a multisample window, fragments that fall
	outside the window's multisample subrectangle are discarded
	(scissored).  By default, the window's multisample rectangle is
	positioned at its window origin.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/shared_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIS.shared_multisample import *
from OpenGL.raw.GLX.SGIS.shared_multisample import _EXTENSION_NAME

def glInitSharedMultisampleSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.shader_pixel_local_storage

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.shader_pixel_local_storage to provide a more 
Python-friendly API

Overview (from the spec)
	
	Techniques such as deferred shading and deferred lighting are often
	implemented by attaching multiple color render targets to a framebuffer
	object, rendering the required intermediate data, and then sampling from
	this data as textures.  While flexible, this approach consumes a large
	amount of external memory bandwidth, which is at a premium on mobile
	devices.
	
	Observing that the intermediate or "G-buffer" data is often only written to
	and read by shaders executing for the same pixel position, tile-based
	renderers can offer a more efficient alternative by keeping the data on-GPU.
	This allows large amounts of data to be kept per-pixel, with zero external
	memory bandwidth impact.
	
	This extension provides a way for applications to pass information between
	fragment shader invocations covering the same pixel by introducing the
	concept of pixel local storage. Pixel local storage is an on-chip memory
	storage that can be efficiently accessed by fragments being processed by
	the GL. The format of data stored in the pixel local storage is independent
	of the format of the currently attached framebuffer. The data in pixel local
	storage is not written back to main memory. Access to pixel local storage
	is controlled via glEnable and glDisable. If commands that implicitly or
	explicitly flush the GL command stream are issued when pixel local storage
	is enabled then the contents of the pixel local storage becomes undefined
	for subsequent commands.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shader_pixel_local_storage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.shader_pixel_local_storage import *
from OpenGL.raw.GLES2.EXT.shader_pixel_local_storage import _EXTENSION_NAME

def glInitShaderPixelLocalStorageEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GLES1_1_0

This module customises the behaviour of the 
OpenGL.raw.GLES1.VERSION.GLES1_1_0 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GLES1_1_0.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.VERSION.GLES1_1_0 import *
from OpenGL.raw.GLES1.VERSION.GLES1_1_0 import _EXTENSION_NAME

def glInitGles110VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glClipPlanef=wrapper.wrapper(glClipPlanef).setInputArraySize(
    'eqn', 4
)
# INPUT glFogfv.params size not checked against 'pname'
glFogfv=wrapper.wrapper(glFogfv).setInputArraySize(
    'params', None
)
glGetClipPlanef=wrapper.wrapper(glGetClipPlanef).setInputArraySize(
    'equation', 4
)
glGetFloatv=wrapper.wrapper(glGetFloatv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetLightfv=wrapper.wrapper(glGetLightfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetMaterialfv=wrapper.wrapper(glGetMaterialfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexEnvfv=wrapper.wrapper(glGetTexEnvfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexParameterfv=wrapper.wrapper(glGetTexParameterfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glLightModelfv.params size not checked against 'pname'
glLightModelfv=wrapper.wrapper(glLightModelfv).setInputArraySize(
    'params', None
)
# INPUT glLightfv.params size not checked against 'pname'
glLightfv=wrapper.wrapper(glLightfv).setInputArraySize(
    'params', None
)
glLoadMatrixf=wrapper.wrapper(glLoadMatrixf).setInputArraySize(
    'm', 16
)
# INPUT glMaterialfv.params size not checked against 'pname'
glMaterialfv=wrapper.wrapper(glMaterialfv).setInputArraySize(
    'params', None
)
glMultMatrixf=wrapper.wrapper(glMultMatrixf).setInputArraySize(
    'm', 16
)
# INPUT glPointParameterfv.params size not checked against 'pname'
glPointParameterfv=wrapper.wrapper(glPointParameterfv).setInputArraySize(
    'params', None
)
# INPUT glTexEnvfv.params size not checked against 'pname'
glTexEnvfv=wrapper.wrapper(glTexEnvfv).setInputArraySize(
    'params', None
)
# INPUT glTexParameterfv.params size not checked against 'pname'
glTexParameterfv=wrapper.wrapper(glTexParameterfv).setInputArraySize(
    'params', None
)
# INPUT glBufferData.data size not checked against size
glBufferData=wrapper.wrapper(glBufferData).setInputArraySize(
    'data', None
)
# INPUT glBufferSubData.data size not checked against size
glBufferSubData=wrapper.wrapper(glBufferSubData).setInputArraySize(
    'data', None
)
glClipPlanex=wrapper.wrapper(glClipPlanex).setInputArraySize(
    'equation', 4
)
# INPUT glColorPointer.pointer size not checked against 'size,type,stride'
glColorPointer=wrapper.wrapper(glColorPointer).setInputArraySize(
    'pointer', None
)
# INPUT glCompressedTexImage2D.data size not checked against imageSize
glCompressedTexImage2D=wrapper.wrapper(glCompressedTexImage2D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage2D.data size not checked against imageSize
glCompressedTexSubImage2D=wrapper.wrapper(glCompressedTexSubImage2D).setInputArraySize(
    'data', None
)
# INPUT glDeleteBuffers.buffers size not checked against n
glDeleteBuffers=wrapper.wrapper(glDeleteBuffers).setInputArraySize(
    'buffers', None
)
# INPUT glDeleteTextures.textures size not checked against n
glDeleteTextures=wrapper.wrapper(glDeleteTextures).setInputArraySize(
    'textures', None
)
# INPUT glDrawElements.indices size not checked against 'count,type'
glDrawElements=wrapper.wrapper(glDrawElements).setInputArraySize(
    'indices', None
)
# INPUT glFogxv.param size not checked against 'pname'
glFogxv=wrapper.wrapper(glFogxv).setInputArraySize(
    'param', None
)
glGetBooleanv=wrapper.wrapper(glGetBooleanv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetBufferParameteriv=wrapper.wrapper(glGetBufferParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetClipPlanex=wrapper.wrapper(glGetClipPlanex).setInputArraySize(
    'equation', 4
)
glGenBuffers=wrapper.wrapper(glGenBuffers).setOutput(
    'buffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGenTextures=wrapper.wrapper(glGenTextures).setOutput(
    'textures',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetIntegerv=wrapper.wrapper(glGetIntegerv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glGetLightxv.params size not checked against 'pname'
glGetLightxv=wrapper.wrapper(glGetLightxv).setInputArraySize(
    'params', None
)
# INPUT glGetMaterialxv.params size not checked against 'pname'
glGetMaterialxv=wrapper.wrapper(glGetMaterialxv).setInputArraySize(
    'params', None
)
glGetPointerv=wrapper.wrapper(glGetPointerv).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetTexEnviv=wrapper.wrapper(glGetTexEnviv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glGetTexEnvxv.params size not checked against 'pname'
glGetTexEnvxv=wrapper.wrapper(glGetTexEnvxv).setInputArraySize(
    'params', None
)
glGetTexParameteriv=wrapper.wrapper(glGetTexParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glGetTexParameterxv.params size not checked against 'pname'
glGetTexParameterxv=wrapper.wrapper(glGetTexParameterxv).setInputArraySize(
    'params', None
)
# INPUT glLightModelxv.param size not checked against 'pname'
glLightModelxv=wrapper.wrapper(glLightModelxv).setInputArraySize(
    'param', None
)
# INPUT glLightxv.params size not checked against 'pname'
glLightxv=wrapper.wrapper(glLightxv).setInputArraySize(
    'params', None
)
glLoadMatrixx=wrapper.wrapper(glLoadMatrixx).setInputArraySize(
    'm', 16
)
# INPUT glMaterialxv.param size not checked against 'pname'
glMaterialxv=wrapper.wrapper(glMaterialxv).setInputArraySize(
    'param', None
)
glMultMatrixx=wrapper.wrapper(glMultMatrixx).setInputArraySize(
    'm', 16
)
# INPUT glNormalPointer.pointer size not checked against 'type,stride'
glNormalPointer=wrapper.wrapper(glNormalPointer).setInputArraySize(
    'pointer', None
)
# INPUT glPointParameterxv.params size not checked against 'pname'
glPointParameterxv=wrapper.wrapper(glPointParameterxv).setInputArraySize(
    'params', None
)
# OUTPUT glReadPixels.pixels COMPSIZE(format, type, width, height) 
# INPUT glTexCoordPointer.pointer size not checked against 'size,type,stride'
glTexCoordPointer=wrapper.wrapper(glTexCoordPointer).setInputArraySize(
    'pointer', None
)
# INPUT glTexEnviv.params size not checked against 'pname'
glTexEnviv=wrapper.wrapper(glTexEnviv).setInputArraySize(
    'params', None
)
# INPUT glTexEnvxv.params size not checked against 'pname'
glTexEnvxv=wrapper.wrapper(glTexEnvxv).setInputArraySize(
    'params', None
)
# INPUT glTexImage2D.pixels size not checked against 'format,type,width,height'
glTexImage2D=wrapper.wrapper(glTexImage2D).setInputArraySize(
    'pixels', None
)
# INPUT glTexParameteriv.params size not checked against 'pname'
glTexParameteriv=wrapper.wrapper(glTexParameteriv).setInputArraySize(
    'params', None
)
# INPUT glTexParameterxv.params size not checked against 'pname'
glTexParameterxv=wrapper.wrapper(glTexParameterxv).setInputArraySize(
    'params', None
)
# INPUT glTexSubImage2D.pixels size not checked against 'format,type,width,height'
glTexSubImage2D=wrapper.wrapper(glTexSubImage2D).setInputArraySize(
    'pixels', None
)
# INPUT glVertexPointer.pointer size not checked against 'size,type,stride'
glVertexPointer=wrapper.wrapper(glVertexPointer).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.query_matrix

This module customises the behaviour of the 
OpenGL.raw.GL.OES.query_matrix to provide a more 
Python-friendly API

Overview (from the spec)
	
	Many applications may need to query the contents and status of the
	current matrix at least for debugging purposes, especially as the
	implementations are allowed to implement matrix machinery either in
	any (possibly proprietary) floating point format, or in a fixed point
	format that has the range and accuracy of at least 16.16 (signed 16 bit
	integer part, unsigned 16 bit fractional part).
	
	This extension is intended to allow application to query the components
	of the matrix and also their status, regardless whether the internal
	representation is in fixed point or floating point.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/query_matrix.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OES.query_matrix import *
from OpenGL.raw.GL.OES.query_matrix import _EXTENSION_NAME

def glInitQueryMatrixOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glQueryMatrixxOES=wrapper.wrapper(glQueryMatrixxOES).setOutput(
    'exponent',size=(16,),orPassIn=True
).setOutput(
    'mantissa',size=(16,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_4_3

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_4_3 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_4_3.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_4_3 import *
from OpenGL.raw.GL.VERSION.GL_4_3 import _EXTENSION_NAME

def glInitGl43VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glClearBufferData.data size not checked against 'format,type'
glClearBufferData=wrapper.wrapper(glClearBufferData).setInputArraySize(
    'data', None
)
# INPUT glClearBufferSubData.data size not checked against 'format,type'
glClearBufferSubData=wrapper.wrapper(glClearBufferSubData).setInputArraySize(
    'data', None
)
glGetFramebufferParameteriv=wrapper.wrapper(glGetFramebufferParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetInternalformati64v=wrapper.wrapper(glGetInternalformati64v).setOutput(
    'params',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
# INPUT glInvalidateFramebuffer.attachments size not checked against numAttachments
glInvalidateFramebuffer=wrapper.wrapper(glInvalidateFramebuffer).setInputArraySize(
    'attachments', None
)
# INPUT glInvalidateSubFramebuffer.attachments size not checked against numAttachments
glInvalidateSubFramebuffer=wrapper.wrapper(glInvalidateSubFramebuffer).setInputArraySize(
    'attachments', None
)
# INPUT glMultiDrawArraysIndirect.indirect size not checked against 'drawcount,stride'
glMultiDrawArraysIndirect=wrapper.wrapper(glMultiDrawArraysIndirect).setInputArraySize(
    'indirect', None
)
# INPUT glMultiDrawElementsIndirect.indirect size not checked against 'drawcount,stride'
glMultiDrawElementsIndirect=wrapper.wrapper(glMultiDrawElementsIndirect).setInputArraySize(
    'indirect', None
)
glGetProgramInterfaceiv=wrapper.wrapper(glGetProgramInterfaceiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glGetProgramResourceIndex.name size not checked against 'name'
glGetProgramResourceIndex=wrapper.wrapper(glGetProgramResourceIndex).setInputArraySize(
    'name', None
)
glGetProgramResourceName=wrapper.wrapper(glGetProgramResourceName).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
# INPUT glGetProgramResourceiv.props size not checked against propCount
glGetProgramResourceiv=wrapper.wrapper(glGetProgramResourceiv).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'params',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setInputArraySize(
    'props', None
)
# INPUT glGetProgramResourceLocation.name size not checked against 'name'
glGetProgramResourceLocation=wrapper.wrapper(glGetProgramResourceLocation).setInputArraySize(
    'name', None
)
# INPUT glGetProgramResourceLocationIndex.name size not checked against 'name'
glGetProgramResourceLocationIndex=wrapper.wrapper(glGetProgramResourceLocationIndex).setInputArraySize(
    'name', None
)
# INPUT glDebugMessageControl.ids size not checked against count
glDebugMessageControl=wrapper.wrapper(glDebugMessageControl).setInputArraySize(
    'ids', None
)
# INPUT glDebugMessageInsert.buf size not checked against 'buf,length'
glDebugMessageInsert=wrapper.wrapper(glDebugMessageInsert).setInputArraySize(
    'buf', None
)
glGetDebugMessageLog=wrapper.wrapper(glGetDebugMessageLog).setOutput(
    'ids',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'lengths',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'messageLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'severities',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'sources',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'types',size=lambda x:(x,),pnameArg='count',orPassIn=True
)
# INPUT glPushDebugGroup.message size not checked against 'message,length'
glPushDebugGroup=wrapper.wrapper(glPushDebugGroup).setInputArraySize(
    'message', None
)
# INPUT glObjectLabel.label size not checked against 'label,length'
glObjectLabel=wrapper.wrapper(glObjectLabel).setInputArraySize(
    'label', None
)
glGetObjectLabel=wrapper.wrapper(glGetObjectLabel).setOutput(
    'label',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
# INPUT glObjectPtrLabel.label size not checked against 'label,length'
glObjectPtrLabel=wrapper.wrapper(glObjectPtrLabel).setInputArraySize(
    'label', None
)
glGetObjectPtrLabel=wrapper.wrapper(glGetObjectPtrLabel).setOutput(
    'label',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
glGetPointerv=wrapper.wrapper(glGetPointerv).setOutput(
    'params',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION

from OpenGL.GL.ARB.arrays_of_arrays import *
from OpenGL.GL.ARB.fragment_layer_viewport import *
from OpenGL.GL.ARB.shader_image_size import *
from OpenGL.GL.ARB.ES3_compatibility import *
from OpenGL.GL.ARB.clear_buffer_object import *
from OpenGL.GL.ARB.compute_shader import *
from OpenGL.GL.ARB.copy_image import *
# Extension registry no longer defines these extensions?
#from OpenGL.GL.ARB.debug_group import *
#from OpenGL.GL.ARB.debug_label import *
#from OpenGL.GL.ARB.debug_output2 import *
from OpenGL.GL.KHR.debug import *
from OpenGL.GL.ARB.explicit_uniform_location import *
from OpenGL.GL.ARB.framebuffer_no_attachments import *
from OpenGL.GL.ARB.internalformat_query2 import *
from OpenGL.GL.ARB.invalidate_subdata import *
from OpenGL.GL.ARB.multi_draw_indirect import *
from OpenGL.GL.ARB.program_interface_query import *
from OpenGL.GL.ARB.robust_buffer_access_behavior import *
from OpenGL.GL.ARB.shader_storage_buffer_object import *
from OpenGL.GL.ARB.stencil_texturing import *
from OpenGL.GL.ARB.texture_buffer_range import *
from OpenGL.GL.ARB.texture_query_levels import *
from OpenGL.GL.ARB.texture_storage_multisample import *
from OpenGL.GL.ARB.texture_view import *
from OpenGL.GL.ARB.vertex_attrib_binding import *



'''OpenGL extension NV.shading_rate_image

This module customises the behaviour of the 
OpenGL.raw.GL.NV.shading_rate_image to provide a more 
Python-friendly API

Overview (from the spec)
	
	By default, OpenGL runs a fragment shader once for each pixel covered by a
	primitive being rasterized.  When using multisampling, the outputs of that
	fragment shader are broadcast to each covered sample of the fragment's
	pixel.  When using multisampling, applications can also request that the
	fragment shader be run once per color sample (when using the "sample"
	qualifier on one or more active fragment shader inputs), or run a fixed
	number of times per pixel using SAMPLE_SHADING enable and the
	MinSampleShading frequency value.  In all of these approaches, the number
	of fragment shader invocations per pixel is fixed, based on API state.
	
	This extension allows applications to bind and enable a shading rate image
	that can be used to vary the number of fragment shader invocations across
	the framebuffer.  This can be useful for applications like eye tracking
	for virtual reality, where the portion of the framebuffer that the user is
	looking at directly can be processed at high frequency, while distant
	corners of the image can be processed at lower frequency.  The shading
	rate image is an immutable-format two-dimensional or two-dimensional array
	texture that uses a format of R8UI.  Each texel represents a fixed-size
	rectangle in the framebuffer, covering 16x16 pixels in the initial
	implementation of this extension.  When rasterizing a primitive covering
	one of these rectangles, the OpenGL implementation reads the texel in the
	bound shading rate image and looks up the fetched value in a palette of
	shading rates.  The shading rate used can vary from (finest) 16 fragment
	shader invocations per pixel to (coarsest) one fragment shader invocation
	for each 4x4 block of pixels.
	
	When this extension is advertised by an OpenGL implementation, the
	implementation must also support the GLSL extension
	"GL_NV_shading_rate_image" (documented separately), which provides new
	built-in variables that allow fragment shaders to determine the effective
	shading rate used for each fragment.  Additionally, the GLSL extension also
	provides new layout qualifiers allowing the interlock functionality provided
	by ARB_fragment_shader_interlock to guarantee mutual exclusion across an
	entire fragment when the shading rate specifies multiple pixels per fragment
	shader invocation.
	
	Note that this extension requires the use of a framebuffer object; the
	shading rate image and related state are ignored when rendering to the
	default framebuffer.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shading_rate_image.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.shading_rate_image import *
from OpenGL.raw.GL.NV.shading_rate_image import _EXTENSION_NAME

def glInitShadingRateImageNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetShadingRateImagePaletteNV=wrapper.wrapper(glGetShadingRateImagePaletteNV).setInputArraySize(
    'rate', 1
)
glGetShadingRateSampleLocationivNV=wrapper.wrapper(glGetShadingRateSampleLocationivNV).setInputArraySize(
    'location', 3
)
# INPUT glShadingRateImagePaletteNV.rates size not checked against count
glShadingRateImagePaletteNV=wrapper.wrapper(glShadingRateImagePaletteNV).setInputArraySize(
    'rates', None
)
# INPUT glShadingRateSampleOrderCustomNV.locations size not checked against 'rate,samples'
glShadingRateSampleOrderCustomNV=wrapper.wrapper(glShadingRateSampleOrderCustomNV).setInputArraySize(
    'locations', None
)
### END AUTOGENERATED SECTION